@@ -14,13 +14,21 @@ class DaikinWSConnection:
         self._session: ClientSession = session
         self._client = None
         self._timeout = timeout
+        self._address = f"ws://{self._host}/mca"
+
+    @property
+    def host(self):
+        return self._host
+
+    @property
+    def ws_address(self):
+        return self._address
 
     async def connect(self):
-        address = f"ws://{self._host}/mca"
-        self._client = await self._session.ws_connect(address)
+        self._client = await self._session.ws_connect(self.ws_address)
 
     async def close(self):
-        self._client.close()
+        await self._client.close()
 
     async def request(self, dest, payload=None, wait_for_response=True, assert_response_fn=None):
 
